@@ -1,12 +1,13 @@
 #' A class that contains named data frames.
 #'
-#' The PivotData class stores all of the data frames associated with a pivot table.
+#' The PivotData class stores all of the data frames associated with a pivot
+#' table.
 #'
 #' @docType class
 #' @importFrom R6 R6Class
 #' @import jsonlite
-#' @keywords data frame
-#' @return Object of \code{\link{R6Class}} with properties and methods that help quickly storing and retrieving data frames.
+#' @return Object of \code{\link{R6Class}} with properties and methods that help
+#'   quickly storing and retrieving data frames.
 #' @format \code{\link{R6Class}} object.
 #' @examples
 #' # This class should only be created by the pivot table.
@@ -15,14 +16,22 @@
 
 #' @section Methods:
 #' \describe{
-#'   \item{Documentation}{For more complete explanations and examples please see the extensive vignettes supplied with this package.}
-#'   \item{\code{new(...)}}{Create a new pivot data container, specifying the field value documented above.}
+#'   \item{Documentation}{For more complete explanations and examples please see
+#'   the extensive vignettes supplied with this package.}
+#'   \item{\code{new(...)}}{Create a new pivot data container, specifying the
+#'   field value documented above.}
 #'
-#'   \item{\code{addData(df, dataName)}}{And a data frame to the pivot table, specifying a name that can be used to easily retrieve it or refer to it later.}
-#'   \item{\code{getData(dataName)}}{Get the data frame with the specified name.}
-#'   \item{\code{isKnownData(dataName))}}{Check if a data frame exists with the specified name.}
-#'   \item{\code{asList()}}{Get a list representation of the contained data frames.}
-#'   \item{\code{asJSON()}}{Get a JSON representation of the contained data frames.}
+#'   \item{\code{addData(df, dataName)}}{And a data frame to the pivot table,
+#'   specifying a name that can be used to easily retrieve it or refer to it
+#'   later.}
+#'   \item{\code{getData(dataName)}}{Get the data frame with the specified
+#'   name.}
+#'   \item{\code{isKnownData(dataName))}}{Check if a data frame exists with the
+#'   specified name.}
+#'   \item{\code{asList()}}{Get a list representation of the contained data
+#'   frames.}
+#'   \item{\code{asJSON()}}{Get a JSON representation of the contained data
+#'   frames.}
 #' }
 
 PivotData <- R6::R6Class("PivotData",
@@ -41,8 +50,8 @@ PivotData <- R6::R6Class("PivotData",
      private$p_parentPivot$message("PivotData$addData", "Adding data...", list(dataName=dataName, df=private$getDfStr(df)))
      dn <- dataName
      if(is.null(dn)) dn <- deparse(substitute(df))
-     if(is.null(dn)) stop("PivotData$addData(): Please specify a name for the data frame.")
-     if(length(dn)==0) stop("PivotData$addData(): Please specify a name for the data frame.")
+     if(is.null(dn)) stop("PivotData$addData(): Please specify a name for the data frame.", call. = FALSE)
+     if(length(dn)==0) stop("PivotData$addData(): Please specify a name for the data frame.", call. = FALSE)
      if(is.null(private$p_defaultData)) {
        private$p_defaultData <- df
        private$p_defaultName <- dn
